structpbutil

package
v0.74.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NormalizeMap

func NormalizeMap(m map[string]any) map[string]any

NormalizeMap converts typed string-key maps and typed slices into shapes accepted by structpb.NewStruct, preserving values recursively.

func NormalizeValue

func NormalizeValue(v any) any

NormalizeValue converts typed map/slice values recursively while leaving unsupported values in place so structpb.NewStruct can return its own error.

Types

This section is empty.

Jump to