Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NormalizeMap ¶
NormalizeMap converts typed string-key maps and typed slices into shapes accepted by structpb.NewStruct, preserving values recursively.
func NormalizeValue ¶
NormalizeValue converts typed map/slice values recursively while leaving unsupported values in place so structpb.NewStruct can return its own error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.